@@ -2,6 +2,7 @@
 
 # importing libraries
 import os
+import gc
 import rsa
 import string
 import secrets
@@ -318,7 +319,6 @@ def one_time_pad_encrypt(message:str, key:str):
     # getting the length of the message bytes
     message_length = len(message.encode())
     # coverting the message to bytes
-    print (key_length, message_length)
     message_bytes = message.encode()
     # ensuring message length is a multiple of key length
     if message_length % key_length != 0:
@@ -418,6 +418,11 @@ def keyToEnglish(key:bytes):
     return words
 
 
+def collect():
+    gc.collect()
+    return 0
+
+
 class Ciphers: # tested
     """
     A class for ciphering/deciphering operations.
@@ -866,7 +871,7 @@ class Ciphers: # tested
         except AssertionError:
             raise NoKeyError("No key was provided for decryption")
         f = Fernet(key)
-        decrypted_text = f.encrypt(encrypted_string)
+        decrypted_text = f.decrypt(encrypted_string)
         return decrypted_text
 
 
@@ -1610,13 +1615,6 @@ def init_diagonostic():
         pass
     except Exception as e:
         print (f"failure occurred during edge case test: {e}")
-    # deleting all variables
-    for i in globals():
-        del globals()[i]
-    for i in locals():
-        del locals()[i]
+    gc.collect()
     return 0
 
-
-if __name__ == "__main__":
-    init_diagonostic()
